package com.therealbluepandabear.pixapencil.tooltests.tests

import android.graphics.Color
import androidx.test.ext.junit.rules.ActivityScenarioRule
import androidx.test.ext.junit.runners.AndroidJUnit4
import androidx.test.filters.LargeTest
import com.therealbluepandabear.pixapencil.activities.canvas.CanvasActivity
import com.therealbluepandabear.pixapencil.activities.canvas.canvascommands.overrideSetPixel
import com.therealbluepandabear.pixapencil.algorithms.CircleAlgorithm
import com.therealbluepandabear.pixapencil.algorithms.FloodFillAlgorithm
import com.therealbluepandabear.pixapencil.algorithms.RectanglePreviewAlgorithm
import com.therealbluepandabear.pixapencil.extensions.getPixel
import com.therealbluepandabear.pixapencil.models.Coordinates
import com.therealbluepandabear.pixapencil.tooltests.helper.ToolTestsHelper
import org.junit.Rule
import org.junit.Test
import org.junit.runner.RunWith

@RunWith(AndroidJUnit4::class)
@LargeTest
class FillToolTests {
    @get:Rule
    val activityRule = ActivityScenarioRule(CanvasActivity::class.java)

    @Test
    fun ftt_1() {
        activityRule.scenario.onActivity {
            ToolTestsHelper.prepare(it)

            it.canvasCommandsHelperInstance.overrideSetPixel(Coordinates(0,0), Color.YELLOW)
            it.canvasCommandsHelperInstance.overrideSetPixel(Coordinates(0,1), Color.YELLOW)
            it.canvasCommandsHelperInstance.overrideSetPixel(Coordinates(1,2), Color.YELLOW)
            it.canvasCommandsHelperInstance.overrideSetPixel(Coordinates(2,3), Color.YELLOW)
            it.canvasCommandsHelperInstance.overrideSetPixel(Coordinates(3,3), Color.YELLOW)
            it.canvasCommandsHelperInstance.overrideSetPixel(Coordinates(4,3), Color.YELLOW)
            it.canvasCommandsHelperInstance.overrideSetPixel(Coordinates(5,4), Color.YELLOW)
            it.canvasCommandsHelperInstance.overrideSetPixel(Coordinates(6,5), Color.YELLOW)
            it.canvasCommandsHelperInstance.overrideSetPixel(Coordinates(7,4), Color.YELLOW)
            it.canvasCommandsHelperInstance.overrideSetPixel(Coordinates(7,3), Color.YELLOW)
            it.canvasCommandsHelperInstance.overrideSetPixel(Coordinates(7,2), Color.YELLOW)
            it.canvasCommandsHelperInstance.overrideSetPixel(Coordinates(6,1), Color.YELLOW)
            it.canvasCommandsHelperInstance.overrideSetPixel(Coordinates(5,0), Color.YELLOW)

            val floodFillAlgorithm = FloodFillAlgorithm(it.primaryAlgorithmInfoParameter)
            floodFillAlgorithm.compute(Coordinates(1, 1))

            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1, 0)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 0)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 0)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 0)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1, 1)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 1)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 1)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 1)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 1)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 4)) == Color.BLACK)
        }
    }

    @Test
    fun ftt_2() {
        activityRule.scenario.onActivity {
            ToolTestsHelper.prepare(it)

            val rectangleAlgorithm = RectanglePreviewAlgorithm(it.primaryAlgorithmInfoParameter)
            rectangleAlgorithm.compute(Coordinates(0, 0), Coordinates(8, 5))

            it.primaryAlgorithmInfoParameter.color = Color.BLUE
            val floodFillAlgorithm = FloodFillAlgorithm(it.primaryAlgorithmInfoParameter)
            floodFillAlgorithm.compute(Coordinates(1,1))

            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1,1)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2,1)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3,1)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4,1)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5,1)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6,1)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7,1)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1,2)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2,2)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3,2)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4,2)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5,2)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6,2)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7,2)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1,3)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2,3)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3,3)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4,3)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5,3)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6,3)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7,3)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1,4)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2,4)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3,4)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4,4)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5,4)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6,4)) == Color.BLUE)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7,4)) == Color.BLUE)
        }
    }

    @Test
    fun ftt_3() {
        activityRule.scenario.onActivity {
            ToolTestsHelper.prepare(it)

            val circleAlgorithm = CircleAlgorithm(it.primaryAlgorithmInfoParameter)
            circleAlgorithm.compute(Coordinates(0, 0), Coordinates(7, 7))

            it.primaryAlgorithmInfoParameter.color = Color.YELLOW
            val floodFillAlgorithm = FloodFillAlgorithm(it.primaryAlgorithmInfoParameter)
            floodFillAlgorithm.compute(Coordinates(2,2))

            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2,1)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3,1)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4,1)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5,1)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1,2)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2,2)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3,2)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4,2)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5,2)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6,2)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1,3)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2,3)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3,3)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4,3)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5,3)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6,3)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1,4)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2,4)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3,4)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4,4)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5,4)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6,4)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1,5)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2,5)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3,5)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4,5)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5,5)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6,5)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2,6)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3,6)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4,6)) == Color.YELLOW)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5,6)) == Color.YELLOW)
        }
    }

    @Test
    fun ftt_4() {
        activityRule.scenario.onActivity {
            ToolTestsHelper.prepare(it)

            it.primaryAlgorithmInfoParameter.color = Color.YELLOW
            val circleAlgorithm = CircleAlgorithm(it.primaryAlgorithmInfoParameter)
            circleAlgorithm.compute(Coordinates(0, 0), Coordinates(29, 29))

            it.primaryAlgorithmInfoParameter.color = Color.BLACK
            val floodFillAlgorithm = FloodFillAlgorithm(it.primaryAlgorithmInfoParameter)
            floodFillAlgorithm.compute(Coordinates(5,5))

            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 1)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 1)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 1)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 1)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 1)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 1)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 1)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 1)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(26, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(27, 8)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(26, 7)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(26, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 6)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 3)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 2)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(27, 9)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(26, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 5)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 4)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(27, 10)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(26, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(27, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(26, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(28, 11)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(27, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(26, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(28, 12)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(27, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(26, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 26)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 26)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(28, 13)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(27, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(26, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 26)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 27)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 26)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 27)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(28, 14)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(27, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(26, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 26)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 27)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(14, 28)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 26)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 27)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(13, 28)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(28, 15)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(27, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(26, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 26)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 27)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(15, 28)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 26)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 27)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(12, 28)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(28, 16)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(27, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(26, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 26)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 27)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(16, 28)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(1, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 26)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(10, 27)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(11, 28)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(28, 17)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(27, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(26, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 26)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 27)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(17, 28)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 26)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(9, 27)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(28, 18)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(27, 19)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(26, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 26)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(19, 27)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(18, 28)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(2, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(3, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(6, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(7, 26)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(8, 27)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(27, 20)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(26, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 26)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(20, 27)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(4, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(5, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(27, 21)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(26, 22)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 23)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(23, 25)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(22, 26)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(21, 27)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(25, 24)) == Color.BLACK)
            assert(it.binding.activityCanvasPixelGridView.pixelGridViewBitmap.getPixel(Coordinates(24, 25)) == Color.BLACK)
        }
    }
}